@@ -9,12 +9,14 @@ require DynaLoader;
 our @ISA = qw(Exporter DynaLoader);
 our @EXPORT_OK = qw(minify);
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 bootstrap JavaScript::Minifier::XS $VERSION;
 
 1;
 
+=for stopwords minifies minified minifier minification tokenizing EOL
+
 =head1 NAME
 
 JavaScript::Minifier::XS - XS based JavaScript minifier
@@ -22,12 +24,13 @@ JavaScript::Minifier::XS - XS based JavaScript minifier
 =head1 SYNOPSIS
 
   use JavaScript::Minifier::XS qw(minify);
-  $minified = minify($js);
+  my $js       = '...';
+  my $minified = minify($js);
 
 =head1 DESCRIPTION
 
 C<JavaScript::Minifier::XS> is a JavaScript "minifier"; its designed to remove
-un-necessary whitespace and comments from JavaScript files, which also B<not>
+unnecessary whitespace and comments from JavaScript files, which also B<not>
 breaking the JavaScript.
 
 C<JavaScript::Minifier::XS> is similar in function to C<JavaScript::Minifier>,
@@ -46,7 +49,7 @@ caller.
 
 =head1 HOW IT WORKS
 
-C<JavaScript::Minifier::XS> minifies the JavaScript by removing un-necessary
+C<JavaScript::Minifier::XS> minifies the JavaScript by removing unnecessary
 whitespace from JavaScript documents.  Comments (both block and line) are also
 removed, I<except> when (a) they contain the word "copyright" in them, or (b)
 they're needed to implement "IE Conditional Compilation".
@@ -80,7 +83,7 @@ result is the first whitespace character in the run.
 
 =head2 Pass 3: Pruning
 
-We then go back through the token list and prune and remove un-necessary
+We then go back through the token list and prune and remove unnecessary
 tokens.
 
 =over
